# frozen_string_literal: true

require 'alphavantagerb'

module Chg
  # CLI interface
  class CLI
    MissingKey = ArgumentError.new('Missing ALPHAVANTAGE_KEY env. var')
    attr_reader :key

    def initialize(key)
      @key = key
    end

    def usage
      "Usage: #{program} <from> <to> [amount = 1]"
    end

    def change(from, to, amount)
      changed = amount * rate(from, to)
      "#{amount} #{from.upcase} = #{changed} #{to.upcase}"
    end

    def rate(from, to)
      raise MissingKey unless key

      xchg = Alphavantage::Exchange.new(from: from, to: to, key: key).now
      xchg.exchange_rate.to_f
    end

    private

    def program
      $PROGRAM_NAME.sub(%r{.*/}, '')
    end
  end
end
